@@ -34,15 +34,13 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-util.h>
 
 /* Constants */
 #define STRING_ARRAY_DEFAULT_TOKENS_DELIMETER ","
 #define PREFERENCES_SORT_ORDER_MANUALLY 100
 
 /* Path for gnome-vfs preferences */
-static const char *EXTRA_MONITOR_PATHS[] = { "/system/gnome_vfs",
-					     "/desktop/gnome/file_views",
+static const char *EXTRA_MONITOR_PATHS[] = { "/desktop/gnome/file_views",
 					     NULL };
 
 /* Forward declarations */
@@ -96,7 +94,9 @@ static EelEnumerationEntry file_size_enum_entries[] = {
 	{ "5242880",	    N_("5 MB"),		5242880 },
 	{ "10485760",	    N_("10 MB"),	10485760 },
 	{ "104857600",	    N_("100 MB"),	104857600 },
-	{ "1073741824",     N_("1 GB"),         1073741824 }
+	{ "1073741824",     N_("1 GB"),         1073741824 },
+	{ "2147483648",     N_("2 GB"),         2147483648U },
+ 	{ "4294967295",     N_("4 GB"),         4294967295U }
 };
 
 static EelEnumerationEntry click_policy_enum_entries[] = {
@@ -279,6 +279,10 @@ static const PreferenceDefault preference_defaults[] = {
 	  NULL, NULL,
 	  "executable_text_activation"
 	},
+	{ NAUTILUS_PREFERENCES_INSTALL_MIME_ACTIVATION,
+	  PREFERENCE_BOOLEAN,
+	  GINT_TO_POINTER (TRUE)
+	},
 	{ NAUTILUS_PREFERENCES_THEME,
 	  PREFERENCE_STRING,
 	  "default"
@@ -814,4 +818,12 @@ nautilus_global_preferences_init (void)
 	/* Preload everything in a big batch */
 	eel_gconf_preload_cache ("/apps/nautilus/preferences",
 				 GCONF_CLIENT_PRELOAD_ONELEVEL);
+	eel_gconf_preload_cache ("/desktop/gnome/file_views",
+				 GCONF_CLIENT_PRELOAD_ONELEVEL);
+	
+	/* These are always needed for the desktop */
+	eel_gconf_preload_cache ("/apps/nautilus/desktop",
+				 GCONF_CLIENT_PRELOAD_ONELEVEL);
+	eel_gconf_preload_cache ("/apps/nautilus/icon_view",
+				 GCONF_CLIENT_PRELOAD_ONELEVEL);
 }
