@@ -25,16 +25,12 @@
 #include "nautilus-location-dialog.h"
 
 #include <eel/eel-gtk-macros.h>
-#include <eel/eel-vfs-extensions.h>
 #include <eel/eel-stock-dialogs.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkstock.h>
-#include <libgnomeui/gnome-help.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gtk/gtk.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include "nautilus-location-entry.h"
 #include "nautilus-desktop-window.h"
+#include <glib/gi18n.h>
 
 struct _NautilusLocationDialogDetails {
 	GtkWidget *entry;
@@ -76,16 +72,14 @@ nautilus_location_dialog_destroy (GtkObject *object)
 static void
 open_current_location (NautilusLocationDialog *dialog)
 {
-	char *uri;
+	GFile *location;
 	char *user_location;
 	
 	user_location = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->entry), 0, -1);
-	uri = gnome_vfs_make_uri_from_input (user_location);
+	location = g_file_parse_name (user_location);
+	nautilus_window_go_to (dialog->details->window, location);
+	g_object_unref (location);
 	g_free (user_location);
-
-	nautilus_window_go_to (dialog->details->window, uri);
-
-	g_free (uri);
 }
 
 static void
@@ -107,10 +101,9 @@ response_callback (NautilusLocationDialog *dialog,
 		break;
 	case GTK_RESPONSE_HELP :
 		error = NULL;
-		gnome_help_display_desktop_on_screen (NULL, "user-guide", "user-guide.xml",
-						      "nautilus-open-location",
-						      gtk_window_get_screen (GTK_WINDOW (dialog)),
-						      &error);
+		gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (dialog)),
+			      "ghelp:user-guide#nautilus-open-location",
+			      gtk_get_current_event_time (), &error);
 		if (error) {
 			eel_show_error_dialog (_("There was an error displaying help."), error->message,
 					       GTK_WINDOW (dialog));
@@ -205,8 +198,9 @@ nautilus_location_dialog_init (NautilusLocationDialog *dialog)
 GtkWidget *
 nautilus_location_dialog_new (NautilusWindow *window)
 {
+	NautilusWindowSlot *slot;
 	GtkWidget *dialog;
-	char *location;
+	GFile *location;
 	char *formatted_location;
 	
 	dialog = gtk_widget_new (NAUTILUS_TYPE_LOCATION_DIALOG, NULL);
@@ -217,20 +211,20 @@ nautilus_location_dialog_new (NautilusWindow *window)
 				       gtk_window_get_screen (GTK_WINDOW (window)));
 		NAUTILUS_LOCATION_DIALOG (dialog)->details->window = window;
 	}
-	
 
-	location = nautilus_window_get_location (window);
+	slot = window->details->active_slot;
+
+	location = slot->location;
 	if (location != NULL) {
 		if (NAUTILUS_IS_DESKTOP_WINDOW (window)) {
 			formatted_location = g_strdup_printf ("%s/", g_get_home_dir ());
 		} else {
-			formatted_location = eel_format_uri_for_display (location);
+			formatted_location = g_file_get_parse_name (location);
 		}
 		nautilus_entry_set_text (NAUTILUS_ENTRY (NAUTILUS_LOCATION_DIALOG (dialog)->details->entry), formatted_location);
 		gtk_editable_select_region (GTK_EDITABLE (NAUTILUS_LOCATION_DIALOG (dialog)->details->entry), 0, -1);
 		gtk_editable_set_position (GTK_EDITABLE (NAUTILUS_LOCATION_DIALOG (dialog)->details->entry), -1);
 		g_free (formatted_location);
-		g_free (location);
 	}
 	
 	gtk_widget_grab_focus (NAUTILUS_LOCATION_DIALOG (dialog)->details->entry);
