@@ -53,7 +53,6 @@
 #ifdef HAVE_X11_XF86KEYSYM_H
 #include <X11/XF86keysym.h>
 #endif
-#include <libgnomeui/gnome-uidefs.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
@@ -409,7 +408,7 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 	gtk_widget_show (hbox);
 
 	item = gtk_tool_item_new ();
-	gtk_container_set_border_width (GTK_CONTAINER (item), GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (item), 4);
 	gtk_widget_show (GTK_WIDGET (item));
 	gtk_tool_item_set_expand (item, TRUE);
 	gtk_container_add (GTK_CONTAINER (item),  hbox);
@@ -454,11 +453,11 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 	/* Option menu for content view types; it's empty here, filled in when a uri is set.
 	 * Pack it into vbox so it doesn't grow vertically when location bar does. 
 	 */
-	view_as_menu_vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
+	view_as_menu_vbox = gtk_vbox_new (FALSE, 4);
 	gtk_widget_show (view_as_menu_vbox);
 
 	item = gtk_tool_item_new ();
-	gtk_container_set_border_width (GTK_CONTAINER (item), GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (item), 4);
 	gtk_widget_show (GTK_WIDGET (item));
 	gtk_container_add (GTK_CONTAINER (item), view_as_menu_vbox);
 	gtk_toolbar_insert (GTK_TOOLBAR (location_bar),
@@ -489,7 +488,7 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 				 window, G_CONNECT_SWAPPED);
 	
 	item = gtk_tool_item_new ();
-	gtk_container_set_border_width (GTK_CONTAINER (item), GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (item), 4);
 	gtk_widget_show (GTK_WIDGET (item));
 	gtk_container_add (GTK_CONTAINER (item),  window->zoom_control);
 	gtk_toolbar_insert (GTK_TOOLBAR (location_bar),
@@ -532,14 +531,6 @@ always_use_location_entry_changed (gpointer callback_data)
 	} else {
 		nautilus_navigation_window_set_bar_mode (window, NAUTILUS_BAR_PATH);
 	}
-
-	g_signal_handlers_block_by_func (window->details->location_button,
-					 G_CALLBACK (location_button_toggled_cb),
-					 window);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (window->details->location_button), use_entry);
-	g_signal_handlers_unblock_by_func (window->details->location_button,
-					   G_CALLBACK (location_button_toggled_cb),
-					   window);
 }
 
 static void
@@ -1221,79 +1212,7 @@ static NautilusIconInfo *
 real_get_icon (NautilusWindow *window,
 	       NautilusWindowSlot *slot)
 {
-	return nautilus_icon_info_lookup_from_name ("file-manager", 48);
-}
-
-static void
-zoom_level_changed_callback (NautilusView *view,
-                             NautilusNavigationWindow *window)
-{
-	g_assert (NAUTILUS_WINDOW (window)->details->active_slot->content_view == view);
-
-        /* This is called each time the component successfully completed
-         * a zooming operation.
-         */
-        nautilus_zoom_control_set_zoom_level (NAUTILUS_ZOOM_CONTROL (window->zoom_control),
-                                              nautilus_view_get_zoom_level (view));
-}
-
-static void
-real_connect_content_view (NautilusWindow *nautilus_window,
-			   NautilusView *view)
-{
-	NautilusNavigationWindow *window;
-	NautilusWindowSlot *slot;
-
-	window = NAUTILUS_NAVIGATION_WINDOW (nautilus_window);
-	slot = nautilus_window->details->active_slot;
-
-	EEL_CALL_PARENT (NAUTILUS_WINDOW_CLASS, 
-			 connect_content_view, 
-			 (nautilus_window, view));
-
-	g_signal_connect (view, "zoom_level_changed",
-			  G_CALLBACK (zoom_level_changed_callback),
-			  window);
-
-	if (nautilus_view_supports_zooming (view)) {
-		gtk_widget_show (window->zoom_control);
-	} else {
-		gtk_widget_hide (window->zoom_control);
-	}
-
-        /* Update displayed view in menu. Only do this if we're not switching
-         * locations though, because if we are switching locations we'll
-         * install a whole new set of views in the menu later (the current
-         * views in the menu are for the old location).
-         */
-	if (slot->pending_location == NULL) {
-		load_view_as_menu (nautilus_window);
-	}
-}
-
-static void
-real_disconnect_content_view (NautilusWindow *nautilus_window,
-			      NautilusView *view)
-{
-	NautilusNavigationWindow *window;
-
-	window = NAUTILUS_NAVIGATION_WINDOW (nautilus_window);
-
-	EEL_CALL_PARENT (NAUTILUS_WINDOW_CLASS, 
-			 disconnect_content_view, 
-			 (nautilus_window, view));
-
-	g_signal_handlers_disconnect_by_func
-		(view, 
-		 G_CALLBACK (zoom_level_changed_callback), 
-		 window);	
-
-	if (window->zoom_control != NULL) {
-		/* if we run in destroy(), the
- 		 * zoom control is already gone
-		 */
-		gtk_widget_hide (window->zoom_control);
-	}
+	return nautilus_icon_info_lookup_from_name ("system-file-manager", 48);
 }
 
 static void
@@ -1320,6 +1239,9 @@ path_bar_button_pressed_callback (GtkWidget *widget,
 	GFile *location;
 	char *uri;
 
+	g_object_set_data (G_OBJECT (widget), "handle-button-release",
+			   GINT_TO_POINTER (TRUE));
+
 	if (event->button == 3) {
 		slot = nautilus_window_get_active_slot (NAUTILUS_WINDOW (window));
 		view = slot->content_view;
@@ -1337,10 +1259,64 @@ path_bar_button_pressed_callback (GtkWidget *widget,
 		}
 	}
 
+	return FALSE;
+}
+
+static gboolean
+path_bar_button_released_callback (GtkWidget *widget,
+				   GdkEventButton *event,
+				   NautilusNavigationWindow *window)
+{
+	NautilusWindowSlot *slot;
+	NautilusWindowOpenFlags flags;
+	GFile *location;
+	int mask;
+	gboolean handle_button_release;
+
+	mask = event->state & gtk_accelerator_get_default_mod_mask ();
+	flags = 0;
+
+	handle_button_release = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (widget),
+						  "handle-button-release"));
+
+	if (event->type == GDK_BUTTON_RELEASE && handle_button_release) {
+		location = nautilus_path_bar_get_path_for_button (NAUTILUS_PATH_BAR (window->path_bar), widget);
+
+		if (event->button == 2 && mask == 0) {
+			if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ENABLE_TABS)) {
+				flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
+			} else {
+				flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW;
+			}
+		} else if (event->button == 1 && mask == GDK_CONTROL_MASK) {
+			flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW;
+		}
+
+		if (flags != 0) {
+			slot = nautilus_window_get_active_slot (NAUTILUS_WINDOW (window));
+			nautilus_window_slot_info_open_location (slot, location,
+								 NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE,
+								 flags, NULL);
+			g_object_unref (location);
+			return TRUE;
+		}
+
+		g_object_unref (location);
+	}
 
 	return FALSE;
 }
 
+static void
+path_bar_button_drag_begin_callback (GtkWidget *widget,
+				     GdkEventButton *event,
+				     gpointer user_data)
+{
+	g_object_set_data (G_OBJECT (widget), "handle-button-release",
+			   GINT_TO_POINTER (FALSE));
+}
+
+
 static void
 path_bar_path_set_callback (GtkWidget *widget,
 			    GFile *location,
@@ -1366,6 +1342,12 @@ path_bar_path_set_callback (GtkWidget *widget,
 			g_signal_connect (child, "button-press-event",
 					  G_CALLBACK (path_bar_button_pressed_callback),
 					  window);
+			g_signal_connect (child, "button-release-event",
+					  G_CALLBACK (path_bar_button_released_callback),
+					  window);
+			g_signal_connect (child, "drag-begin",
+					  G_CALLBACK (path_bar_button_drag_begin_callback),
+					  window);
 		}
 	}
 
@@ -1500,6 +1482,51 @@ real_sync_search_widgets (NautilusWindow *window)
 	}
 }
 
+
+static void
+real_sync_zoom_widgets (NautilusWindow *nautilus_window)
+{
+	NautilusNavigationWindow *window;
+	NautilusWindowSlot *slot;
+	NautilusView *view;
+	gboolean supports_zooming, can_zoom;
+
+	window = NAUTILUS_NAVIGATION_WINDOW (nautilus_window);
+
+	slot = nautilus_window->details->active_slot;
+	view = slot->content_view;
+
+	EEL_CALL_PARENT (NAUTILUS_WINDOW_CLASS,
+			 sync_zoom_widgets, (nautilus_window));
+
+	if (view == NULL) {
+		/* don't toggle UI state at all. This might be
+		 * wrong, but it prevents flickering when opening
+		 * a new tab and immediately switching to it -
+		 * before view selection.
+		 */
+		return;
+	}
+
+	supports_zooming = nautilus_view_supports_zooming (view);
+	can_zoom = supports_zooming &&
+		   nautilus_view_get_zoom_level (view) >= NAUTILUS_ZOOM_LEVEL_SMALLEST &&
+		   nautilus_view_get_zoom_level (view) <= NAUTILUS_ZOOM_LEVEL_LARGEST;
+
+	if (window->zoom_control != NULL) {
+		if (supports_zooming) {
+			gtk_widget_set_sensitive (window->zoom_control, can_zoom);
+			gtk_widget_show (window->zoom_control);
+			if (can_zoom) {
+				nautilus_zoom_control_set_zoom_level (NAUTILUS_ZOOM_CONTROL (window->zoom_control),
+								      nautilus_view_get_zoom_level (view));
+			}
+		} else {
+			gtk_widget_hide (window->zoom_control);
+		}
+	}
+}
+
 static void
 side_panel_image_changed_callback (NautilusSidebar *side_panel,
                                    gpointer callback_data)
@@ -1609,6 +1636,8 @@ static void
 nautilus_navigation_window_set_bar_mode (NautilusNavigationWindow *window,
 					 NautilusBarMode mode)
 {
+	gboolean use_entry;
+
 	switch (mode) {
 
 	case NAUTILUS_BAR_PATH:
@@ -1629,6 +1658,19 @@ nautilus_navigation_window_set_bar_mode (NautilusNavigationWindow *window,
 		gtk_widget_hide (window->navigation_bar);
 		break;
 	}
+
+	if (mode == NAUTILUS_BAR_NAVIGATION || mode == NAUTILUS_BAR_PATH) {
+		use_entry = (mode == NAUTILUS_BAR_NAVIGATION);
+
+		g_signal_handlers_block_by_func (window->details->location_button,
+						 G_CALLBACK (location_button_toggled_cb),
+						 window);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (window->details->location_button),
+					      use_entry);
+		g_signal_handlers_unblock_by_func (window->details->location_button,
+						   G_CALLBACK (location_button_toggled_cb),
+						   window);
+	}
 }
 
 gboolean
@@ -1954,11 +1996,10 @@ nautilus_navigation_window_class_init (NautilusNavigationWindowClass *class)
 	GTK_WIDGET_CLASS (class)->window_state_event = nautilus_navigation_window_state_event;
 	GTK_WIDGET_CLASS (class)->key_press_event = nautilus_navigation_window_key_press_event;
 	NAUTILUS_WINDOW_CLASS (class)->load_view_as_menu = real_load_view_as_menu;
-	NAUTILUS_WINDOW_CLASS (class)->connect_content_view = real_connect_content_view;
-	NAUTILUS_WINDOW_CLASS (class)->disconnect_content_view = real_disconnect_content_view;
 	NAUTILUS_WINDOW_CLASS (class)->sync_allow_stop = real_sync_allow_stop;
 	NAUTILUS_WINDOW_CLASS (class)->prompt_for_location = real_prompt_for_location;
 	NAUTILUS_WINDOW_CLASS (class)->sync_search_widgets = real_sync_search_widgets;
+	NAUTILUS_WINDOW_CLASS (class)->sync_zoom_widgets = real_sync_zoom_widgets;
 	NAUTILUS_WINDOW_CLASS (class)->sync_title = real_sync_title;
 	NAUTILUS_WINDOW_CLASS (class)->get_icon = real_get_icon;
 	NAUTILUS_WINDOW_CLASS (class)->get_default_size = real_get_default_size;
