@@ -29,7 +29,7 @@
 #ifndef NAUTILUS_SIDEBAR_TITLE_H
 #define NAUTILUS_SIDEBAR_TITLE_H
 
-#include <gtk/gtkvbox.h>
+#include <gtk/gtk.h>
 #include <eel/eel-background.h>
 #include <libnautilus-private/nautilus-file.h>
 
@@ -52,7 +52,7 @@ typedef struct
 	GtkVBoxClass parent_class;
 } NautilusSidebarTitleClass;
 
-GtkType    nautilus_sidebar_title_get_type          (void);
+GType      nautilus_sidebar_title_get_type          (void);
 GtkWidget *nautilus_sidebar_title_new               (void);
 void       nautilus_sidebar_title_set_file          (NautilusSidebarTitle *sidebar_title,
 						     NautilusFile         *file,
