@@ -33,9 +33,6 @@
 #include "nautilus-spatial-window.h"
 #include "nautilus-navigation-window.h"
 
-#include <bonobo/bonobo-ui-component.h>
-#include <bonobo/bonobo-ui-container.h>
-#include <bonobo/bonobo-ui-toolbar-button-item.h>
 #include <libnautilus-private/nautilus-directory.h>
 
 /* FIXME bugzilla.gnome.org 42575: Migrate more fields into here. */
@@ -168,7 +165,7 @@ void               nautilus_window_set_status                            (Nautil
 void               nautilus_window_load_view_as_menus                    (NautilusWindow    *window);
 void               nautilus_window_load_extension_menus                  (NautilusWindow    *window);
 void               nautilus_window_initialize_menus                      (NautilusWindow    *window);
-void               nautilus_window_initialize_menus_constructed          (NautilusWindow    *window);
+void               nautilus_window_remove_trash_monitor_callback         (NautilusWindow    *window);
 void               nautilus_menus_append_bookmark_to_menu                (NautilusWindow    *window, 
                                                                           NautilusBookmark  *bookmark, 
                                                                           const char        *parent_path,
